@@ -10,10 +10,14 @@ module Debci
       pkg =~ /^[a-z0-9][a-z0-9+.-]+$/
     end
 
-    def request_batch_tests(test_requests, requestor)
+    def validate_priority(priority)
+      priority >= 1 && priority <= 10
+    end
+
+    def request_batch_tests(test_requests, requestor, priority = 1)
       test_requests.each do |request|
         request['arch'].each do |arch|
-          request_tests(request['tests'], request['suite'], arch, requestor)
+          request_tests(request['tests'], request['suite'], arch, requestor, priority)
         end
       end
     end
@@ -35,7 +39,15 @@ module Debci
       errors
     end
 
-    def request_tests(tests, suite, arch, requestor)
+    def validate_tests(tests)
+      errors = []
+      tests.each do |test|
+        errors << "Invalid package name: #{test['package']}" unless valid_package_name?(test['package'])
+      end
+      errors
+    end
+
+    def request_tests(tests, suite, arch, requestor, priority = 1)
       jobs = []
       tests.each do |test|
         pkg = test['package']
@@ -48,11 +60,12 @@ module Debci
           date = Time.now
         end
 
+        package = Debci::Package.find_or_create_by!(name: test['package'])
         job = Debci::Job.create!(
-          package: test['package'],
+          package: package,
           suite: suite,
           arch: arch,
-          requestor: requestor,
+          requestor: requestor.username,
           status: status,
           date: date,
           trigger: test['trigger'],
@@ -61,7 +74,7 @@ module Debci
         jobs << job if enqueue
       end
       jobs.each do |job|
-        self.enqueue(job)
+        self.enqueue(job, priority)
       end
     end
   end
